@@ -128,9 +128,9 @@ class AdobeSignClient():
     """
     REDIRECT_URI = "https://poplars.dev/adobe-sign-activate.html"
     BASE_URL = "https://secure.{shard}.adobesign.com"
-    OAUTH_START_PATH = "/public/oauth"
-    OAUTH_TOKEN_PATH = "/oauth/token"
-    OAUTH_REFRESH_PATH = "/oauth/refresh"
+    OAUTH_START_PATH = "/public/oauth/v2"
+    OAUTH_TOKEN_PATH = "/oauth/v2/token"
+    OAUTH_REFRESH_PATH = "/oauth/v2/refresh"
     REST_ROOT = "/api/rest/v6"
     TRANSIENT_DOCS_PATH = "/transientDocuments"
     AGREEMENTS_PATH = "/agreements"
